import 'zone.js';
import { reflectComponentType, } from '@angular/core';
import { NgZone, createComponent } from '@angular/core';
import { createApplication } from '@angular/platform-browser';
import { Subject, takeUntil } from 'rxjs';
export default (element) => {
    return (Component, props, _childHTML) => {
        createApplication({
            providers: [...(Component.clientProviders || [])],
        }).then((appRef) => {
            const zone = appRef.injector.get(NgZone);
            zone.run(() => {
                const componentRef = createComponent(Component, {
                    environmentInjector: appRef.injector,
                    hostElement: element,
                });
                const mirror = reflectComponentType(Component);
                if (props && mirror) {
                    for (const [key, value] of Object.entries(props)) {
                        if (mirror.inputs.some(({ templateName, propName }) => templateName === key || propName === key)) {
                            componentRef.setInput(key, value);
                        }
                    }
                }
                if (mirror?.outputs.length && props?.['data-analog-id']) {
                    const destroySubject = new Subject();
                    element.setAttribute('data-analog-id', props['data-analog-id']);
                    mirror.outputs.forEach(({ templateName, propName }) => {
                        const outputName = templateName || propName;
                        const component = componentRef.instance;
                        component[outputName]
                            .pipe(takeUntil(destroySubject))
                            .subscribe((detail) => {
                            const event = new CustomEvent(outputName, {
                                bubbles: true,
                                cancelable: true,
                                composed: true,
                                detail,
                            });
                            element.dispatchEvent(event);
                        });
                    });
                    appRef.onDestroy(() => {
                        destroySubject.next();
                        destroySubject.complete();
                    });
                }
                appRef.attachView(componentRef.hostView);
            });
        });
    };
};
//# sourceMappingURL=client.js.map